#
# spec file for package solfege
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%define usemyprovides 0

Name:           solfege
Summary:        An ear training program
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
Version:        3.23.4
Release:        6.2
URL:            https://www.gnu.org/software/solfege/
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  libxslt
BuildRequires:  python3-gobject-devel
BuildRequires:  swig
BuildRequires:  texinfo
BuildRequires:  txt2man
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(python3)

Source0:        ftp://alpha.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz
Source1:        lessonfile_editor.1
Source2:        ftp://alpha.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz.sig
Patch0:         solfege-configure-fix.dif
Patch1:         solfege-python-fixcompile.patch
Patch2:         solfege-nogenreadmeetc.patch
# PATCH-FIX-UPSTREAM - sent by mail to tca@gnu - is upstream orphaned?
Patch3:         reproducible.patch
Patch4:         solfege-python-fixtryorder.patch
Requires:       lilypond-fonts-common >= 2.20
Requires:       python3-gobject-Gdk
Requires:       timidity
#Lillypond only builds lilypond-fonts for 64 bit
ExcludeArch:    i586 i686

%description
Solfege is an eartraining program for X written in python, using
the GTK+ and GNOME libraries. To use this software you need some
basic knowledge about music theory. Using solfege you can learn
to recognise melodic and harmonic intervals, compare interval
sizes, sing the intervals the computer asks for, identify chords,
sing chords, scales, dictation and remember rhythmic patterns.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch3 -p1
%patch4 -p1

for i in `grep -rl "/usr/bin/env python "`;do $(chmod 0755 ${i} ; sed -i '1s/^#!.*/#!\/usr\/bin\/python3 /' ${i}) ;done
for i in `grep -rl "!/usr/bin/python"`;do $(chmod 0755 ${i} ; sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i}) ;done

%build
autoreconf -fi

%configure \
    --enable-docbook-stylesheet=%{_datadir}/xml/docbook/stylesheet/nwalsh/current/html/chunker.xsl \
    --disable-oss-sound
make %{?jobs:-j%jobs} all

%install
%makeinstall

%if 0%{?usemyprovides} == 1
# exclude plugins from the provide-list
cat << EOF > %{my_provides}
grep -v %{buildroot}%{_libdir}/%{name} | %{__find_provides}
EOF
chmod 755 %{my_provides}
%define __find_provides %{my_provides}
%endif

%suse_update_desktop_file solfege Education X-SuSE-Music

# This line caused bnc#664826
#rm -f %%{buildroot}/%%{_datadir}/%%{name}/%%{name}/_version.*
%find_lang %{name}
%fdupes -s %{buildroot}
# Fix any .py files with shebangs and wrong permissions.
chmod 0755 %{buildroot}/usr/share/solfege/solfege/_version.py
chmod 0755 %{buildroot}/usr/share/solfege/solfege/parsetree.py
chmod 0755 %{buildroot}/usr/share/solfege/solfege/presetup.py
chmod 0644 %{buildroot}/usr/share/solfege/solfege/_version.py
find %{buildroot}/usr/share/solfege/ -name "*~" -print -delete

%post
#/sbin/ldconfig
if test -e /dev/music;
then break;
else mknod /dev/music u 14 8 > /dev/null;
fi

#%%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-, root, root)
%doc changelog
%license COPYING
%{_bindir}/*
%{_datadir}/solfege
#%%{_libdir}/solfege
%{_mandir}/man1/*.1.gz
%config %{_sysconfdir}/solfege*
%{_datadir}/pixmaps/*
%{_datadir}/applications/*.desktop

%changelog
* Mon Jan  8 2024 Fabio Pesari <fpesari@tuxfamily.org>
- Added solfege-python-fixtryorder.patch to fix startup error when
  _tryorder is None
* Wed Mar 30 2022 Dave Plater <davejplater@gmail.com>
- Excluded 32 bit build, lillypond fonts only build for 64 bit
* Fri Oct 29 2021 Steve Kowalik <steven.kowalik@suse.com>
- Replace missed /usr/bin/python shebangs with python3.
* Thu May  7 2020 Dave Plater <davejplater@gmail.com>
- Fix lilypond font requirement for lilypond-2.20.0
* Mon Feb 24 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort python glob to make
  package build reproducible
* Wed Feb 19 2020 Dave Plater <davejplater@gmail.com>
- Update to version 3.23.4 and remove all traces of python2
- Upstream changes:
  * fix F9 listing user lesson files
  * toneincontext: let the user compare and practise when answering
  wrong
  * toneincontext: remove Give up button
  * port exporting exercises to audio files and creating ear training
  test
  * printouts to python3/gtk3
  * download ALSA: reload moved to importlib
  * Ported winmidi.c to Python 3!!
  * winreg, osutils, filesystem win32 fixes
  * toneincontext: select between number and solfa buttons
  * toneincontext in minor: ask for correct tones
  * toneincontext: clear flashbar after we give up
  * toneincontext: statistics for x last question
  * .solfegerc: sort sections and variable on save
  * toneincontext: let the user set the tempo
  * Fix bug #48079: label for interval accels
* Sat Nov 23 2019 Dave Plater <davejplater@gmail.com>
- Fix build by removing unnecessary makeinfo rebuild of README,
  AUTHORS etc with solfege-nogenreadmeetc.patch.
- Clean up rpm lint errors.
* Mon Sep 19 2016 davejplater@gmail.com
- Update to version 3.22.2
- Bugfix version
- Changelog not up to date backport from unstable GTK3 3.23.x
- Use automatic dependencies and txt2man for > 1320
- Rebased solfege-python-fixcompile.patch
* Mon Nov 10 2014 Led <ledest@gmail.com>
- fix bashism in post script
* Wed Sep 18 2013 stephan.barth@suse.com
- update to version 3.22.1 which contains the following changes from upstream:
  - Adjust some of the short interval names used when selecting intervals to
    practise: u->P1 4->P4, 5->P5, tt->TT, p11->P11, p12->P12, tt8->d12. Added
    long name for intervals from Eleventh to Double Octave.
  - Fixed a bug where the Default profile could not be selected
  - Updated Esperanto, Spanish, Polish, Turkish, Norwegian bokmål, Brazilian
    Portugese and Vietnamese translations.
* Sat Aug  3 2013 stephan.barth@suse.com
- update to version 3.22.0 which contains several steps from the previous
  version
- removed broken script to find Python scripts with bad permissions. Now using
  a command with explicit file location
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Sep 28 2011 davejplater@gmail.com
- Changed license field to GPL-3.0+ as solfege upgraded their
  license February 5, 2008. bnc#720834
- Added post script to create /dev/music if it doesn't exist after
  reading "README" and moved timidity from "Recommends:" to
  "Requires" as solfege needs this for most sound cards to produce
  sound.
* Mon Sep 26 2011 davejplater@gmail.com
- Update to version 3.20.3, cleaned spec file & refreshed patches.
- Upstream changes and new features :
  * Translation updated: French
  * Added Spanish translation of the user manual.
  * User manual spelling fix
  * Added a section in the user manual describing the directory
  structure of user lessonfiles.
  * Quote all labels in the generated user manual theory images.
  This fixes lilypond build problems.
  * solfege.desktop: add GenericName
  * Help->User Exercises (F9) will now only display lesson files in
  USERDATA/.exercises/user/lesson-files since users with lots of
  files would have performance problems.
  * Add a notice in "User Exercises" that files in ~/lessonfiles
  have to be moved into USERDATA/.exercises because future
  releases might not list the files.
  * See http://www.solfege.org/release-notes/ for other new features
  and changes since version 3.18.7
* Wed Jan 19 2011 davejplater@gmail.com
- Removed the line from the install section of the spec file that
  deleted _version.py and caused bnc#664826 :
  "can not start: ImportError: No module named _version"
* Sun Dec 12 2010 davejplater@gmail.com
- Update to 3.18.7
- Upstream changes :
  * Updated Dutch and Italian translations
  * idbyname: fix it so that tests work when expert mode is selected.
  * Upgrade debugtree.txt to the latest file format.
  * ExerciseView: Don't use gtk.SizeGroup when we display many
  exercises since there are performance issues with it.
  * validate_stored_statistics: don't try to delete from the 'tests'
  table, since it should be removed by now.
  * Show dialog explaining things if the database is locked.
  * frontpage: Escape backslash and apostrophe used in titles.
  * Make elembuilder handle questions where the answer is only one
  element. Fixed by Andre Maute.
  * Use different api to get the screen width and height.
  * Make the install target skip compiling the .py files if
  nopycompile=YES
  * Change to use htmldoc for generating the PDF version of the user
  manual
  * Workaround for the bug where 'None' is stored as the key in
  singinterval exercises.
  * Updates to the russian translation of the user manual.
  * Should work with swig 2.0 now. http://bugs.solfege.org/202
  * Fix bug in the preferences window code that let us select accels
  for the idtone exercises.
  * Updated Danish, Russian, Vietnamese and Chinese translations.
  * Don't import tuner.py when running solfege with the --debug option.
  * Give the synth a little time to process program changes by calling
  an extra note_off.
  * Preferences window: Add gui to delete statistics.
  * Resize main window when selecting exercises less scrollbar use.
  * The statistics page of exercises shows the 10 last test results.
  * Front page editor: option to search for strings in lesson file
  titles when selecting lesson files.
  * Export Exercises to Audio Files: add checkbutton that names the
  generated audio files after the answer of the question.
  * Add missing "Repeat Arpeggio" button to sing-the-fifth
  * Updated Esperanto, Brazilian Portugese,Turkish & Persian translation.
  * Spelling fixes by Ruslan Fedyarov and dougkerns
  * Works with Swig 2.0
  * Lots of minor bug fixes and improvements to the code.
* Mon May 24 2010 davejplater@gmail.com
- Update to 3.16.3
- Upstream changes :
  [#] French and Polish translation updates.
  [#] Fix front page editor bug: failed while moving sections
* Thu Apr 15 2010 davejplater@gmail.com
- Update to 3.16.2
-  Merge solfege.dev revno 1553:
  Interval.get_cname should return "Tritone" and not "Diminished Fifth"
-  Remove some debugging code that accidentally was left in
  get_percentage_correct()
* Sun Apr 11 2010 davejplater@gmail.com
- Update to 3.16.1, fix solfege-configure-fix.dif.
- Removed solfege-compileall-fix.diff, it's no longer needed.
- Added solfege-python-fixcompile.patch from tiwai to fix the
  compiled python files to not contain any buildroot references.
- See the ChangeLog file for many changes since 3.14.5 or
  http://www.solfege.org/
* Mon Jun 29 2009 tiwai@suse.de
- updated to 3.14.5:
  * Unicode error during build fixed
* Fri Jun 19 2009 tiwai@suse.de
- updated to 3.14.4:
  * Fix broken link to the related music theory
  * ConflictResolveDialog: set use_underline to False
  * Update src/runtime.py to check that we have at least Python 2.4
    and PyGTK 2.12
  * Updated Danish, Polish, Brazilian Portugues and Russion
    translations
- updated to 3.14.3:
  * Don't print debug statements
  * bugfix: the small buttons representing parts of the dictation
    where all playing the whole music
  * Updated Russian and Finnish trans
  * Fix http://www.solfege.org/SITS-Incoming/NoDescription-HA
  * It should now be possible to build without a X display.
  * Updated translations
- updated to 3.14.1
  * Updated italian, dutch and turkish translations.
* Mon Mar 16 2009 tiwai@suse.de
- updated to 3.14.0:
  * We now require Python 2.4, Gtk+ 2.14 and pygtk 2.14
  * Improved preferences window 'Instruments' tab layout.
  * Better handling of external programs (CSound, MMA and
    lilypond-book), especially on win32.
  * Misc bug fixes, including bug #110, #111 and #112.
    Idtone will now display translated notenames.
* Thu Mar  5 2009 tiwai@suse.de
- updated to 3.12.2:
  * Added Galician translation.
  * Updated french and vietnamese translation.
- fix build without txt2man
* Mon Jan 19 2009 tiwai@suse.de
- updated to version 3.12.0:
  * CSound support.
  * MMA support.
  * New lesson file functions: load, rnc, chordname
  * Allow length modifiers in chord. Contributed by Noam Raphael.
  * Allow lesson names with apostrophe. Contributed by Noam Raphael.
  * Added option in the preferences window to use a web browser
    for reading the user manual.
  * win32: store user created learning trees in user_data(), not
    app_data(). Move file from old to new location at startup.
  * The File->Learning tree submenu is recreated when activated, so
    new learning trees will show up without restarting the program.
  * added gst-launch as a predefined program for playing mediafiles.
    New users will by default use gst-launch
  * learning_tree_editor: add button to delete learning tree
  * Added a few solfa syllable exercises.
  * Insert our share/solfege and lib/solfege to the beginning of
    sys.path to avoid problems with python-mpd
- updated to version 3.12.1:
  * Some updated translations
  * misc bug fixes
* Wed Oct  1 2008 tiwai@suse.de
- updated to version 3.10.4:
  * Fix: run more than one singinterval test before restarting
    the program
  * More in release notes:
    http://www.solfege.org/Solfege/ReleaseNotes
* Tue Mar 18 2008 lrupp@suse.de
- updated to version 3.10.3:
  * practisesheetdlg.py: label string spelling fix
  * bugfix: fix the 3 most difficult csound exercises,
    they where unusable
  * Added an envelope to the CSound instrument used by the
    intonation exercises to give the tone an attach and release
    time.
  * Updated translations
  * Updated the user manual
  * First very simple cadense exercise
  * Check that user/lowest_pitch and user/highest_pitch is valid
    notenames at startup.
- recommend timidity
- build parallel
* Mon Feb 11 2008 tiwai@suse.de
- updated to version 3.10.2:
  * Updated translations
  * Added automatically check for new translations
  * Some cleanup the the makefile rules that build the users
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 3.10.1:
  * minor installer fixes
* Mon Feb  4 2008 tiwai@suse.de
- updated to version 3.10.0:
  * Ear training test print out
  * Lots of internal fixes.
  * Use the Translation Project for all translations.
  * Lots of bug fixes
* Thu Jul 19 2007 tiwai@suse.de
- updated to version 3.8.2:
  * Vietnamese translations
  * Updates to the french translation
  * Bugfix to the lesson file header parser, so that whitespace
    is optional after header, making "header{" work as expected.
* Wed Jun 20 2007 tiwai@suse.de
- updated to version 3.8.1:
  * Bugfix for pygtk 2.6
  * Make the Escape button to close the export dialog
  * Merge autogen.sh tweak from solfege.dev
  * Fix a bug in ask_for_names_changed method
  * MusicDisplaye rat import fix
  * Added a few Norwegian translation
- clean up spec file, use fdupes and find_lang
* Tue May 15 2007 tiwai@suse.de
- updated to version 3.8.0:
  * added the rhythmtapping and rhythmtapping2 modules
  * menu reorganisation
  * export training set feature
  * better error messages if you try to write lesson files
* Thu Mar 15 2007 tiwai@suse.de
- fix build (incompatibility with the recent xml2po).
* Wed Feb 14 2007 tiwai@suse.de
- updated to verision 3.6.5:
  * make osutils.run_external_program work in MS Windows
  * Handle empty string as .wav or .midi file player
  * Unicode fixes for dataparser, lessonfile and
    HarmonicProgressionLabel
  * Updated de.po from Marc Schettke
  * fr.po: updates by Patrick Ficheux
  * added pt_BR translations by Elias Dorneles da Silveira Junior
  * help/Makefile bugfix and updated help/README
  * singinterval: no double accidentals
  * make click on web links in the help browser work again.
* Tue Dec 19 2006 tiwai@suse.de
- updated to version 3.6.4:
  * preferences window fix
  * fix source code encoding
  * fix some po files
* Tue Nov  7 2006 ro@suse.de
- fix icon permissions
* Wed Oct 18 2006 tiwai@suse.de
- updated to version 3.6.3:
  * Added small section about learning trees to the user manual
  * create .solfege/learningtrees if it does not exist
  * Ask if to save the current learning tree
  * po file updates
  * Learning tree editor improvements
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 3.6.1:
  * Add missing music displayer to one scale exercise (sc-maj)
  * Updated italian translation
  * Even more new scale exercises
  * Move lesson file includes to lesson-files/include
  * Add music displayer to the harmonic progression exercises
  * Fix rounding error in auto_new_question timing
  * Lessonfiles should take the arpeggio tempo from the rc file
* Thu Oct  5 2006 tiwai@suse.de
- updated to version 3.6.0:
  * Added the elembuilder module
  * lots of new scale exercises
  * Bug fixes and minor tweaks.
* Fri Aug 18 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Aug 16 2006 tiwai@suse.de
- updated to version 3.4.2:
  * fix random_transpose=yes...
  * learningtree editor fix
  * Fix add lesson learning tree editor bug.
  * Added lessons to practise intervals from second to octave.
  * Added missing tests from 2 harmonic interval exercises.
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
* Tue Jul  4 2006 tiwai@suse.de
- updated to version 3.4.0:
  * A new nameinterval exercise module with exercises.
  * We can have more than one menu with exercises.
  * Fix for that long lasting MS Windows permission bug.
* Tue May 16 2006 tiwai@suse.de
- updated to version 3.2.1
  * major updates, see ChangeLog for details
- enable XML documents via gnome-doc-utils
- clean up of BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 tiwai@suse.de
- updated to version 3.0.5
* Thu Oct 20 2005 tiwai@suse.de
- updated to version 3.0.3.
* Mon Feb 14 2005 tiwai@suse.de
- updated to version 2.1.90.
  using easybuild tarball.
* Wed Nov 24 2004 tiwai@suse.de
- Updated to version 2.0.6.
- Fixed strict-aliasing compile warnings.
* Mon Nov  1 2004 mmj@suse.de
- locale rename no to nb
* Thu Oct 14 2004 ro@suse.de
- added libgcrypt, libgpg-error to neededforbuild
* Fri Sep 17 2004 ro@suse.de
- added docbook_4 sgml-skel to neededforbuild
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 2.0.5.
* Mon Feb 16 2004 tiwai@suse.de
- updated to version 2.0.4 (major update).
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Thu Aug 28 2003 tiwai@suse.de
- fixed the module path name for the new SWIG (bug #29550).
- fixed the warning popup in operation.
* Mon Aug 11 2003 adrian@suse.de
- add Categories
* Fri Jul 25 2003 tiwai@suse.de
- fixed the gnome application path.
- fixed the detectio of python directories.
* Tue Jul 22 2003 tiwai@suse.de
- initial version: 1.4.10.
